"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.extractMAC = extractMAC;
exports.getMAC = getMAC;
exports.isMAC = isMAC;

var _child_process = require("child_process");

// Import
const isWindows = process.platform.startsWith('win');
const macRegex = /(?:[a-z0-9]{2}[:-]){5}[a-z0-9]{2}/gi;
const zeroRegex = /(?:[0]{2}[:-]){5}[0]{2}/;
const winMacLineRegex = /\\Device\\Tcpip_/gi; // Helpers

function asyncExec(command) {
  return new Promise(function (resolve, reject) {
    (0, _child_process.exec)(command, function (err, stdout, stderr) {
      if (err) return reject(err);
      resolve(stdout);
    });
  });
}
/** Extract Interface */


function extractInterface(iface, input) {
  const ifaceRegExp = new RegExp(`${iface}[:\\s]`);
  const lines = input.split(/\r?\n/g);
  let result = '';
  let padding;

  for (const line of lines) {
    if (result === '') {
      if (ifaceRegExp.test(line)) {
        result += line;
      }

      continue;
    } else if (padding == null) {
      const match = /^(\s+)/.exec(line);

      if (match) {
        result += '\n' + line;
        padding = new RegExp(`^${match[1]}`);
        continue;
      }
    } else {
      const match = padding.exec(line);

      if (match) {
        result += '\n' + line;
        continue;
      }
    }

    break;
  }

  if (result === '') {
    throw new Error(`Failed to extract the interface ${iface} from\n${input}`);
  }

  return result;
}
/* Extract the Mac address info line where platform is win */


function extractMacLine(input) {
  winMacLineRegex.lastIndex = 0;
  const lines = input.split(/\r?\n/g).filter(v => v);
  const macLine = lines.find(v => winMacLineRegex.test(v));
  return macLine || input;
}
/** Extract the MAC address from a string */


function extractMAC(input, iface) {
  // Prepare
  if (iface) {
    input = extractInterface(iface, input);
  } // Find a valid mac address


  macRegex.lastIndex = 0; // reset
  // Find window mac address line

  if (isWindows) {
    input = extractMacLine(input);
  }

  let match;
  /* eslint no-cond-assign:0 */

  while (match = macRegex.exec(input)) {
    const macAddress = match[0];
    const isZero = zeroRegex.test(macAddress);

    if (isZero === false) {
      return macAddress;
    }
  } // We have no mac address so return an error


  throw new Error(`Failed to extract the MAC address from\n${input}`);
}
/** Get the first proper MAC address */


async function getMAC(iface) {
  const command = isWindows ? '%SystemRoot%/System32/getmac.exe' : '/sbin/ifconfig -a || /sbin/ip link';
  const stdout = await asyncExec(command);
  return extractMAC(stdout, iface);
} // Is Mac


function isMAC(macAddress) {
  var _String$match;

  macRegex.lastIndex = 0; // reset

  return ((_String$match = String(macAddress).match(macRegex)) === null || _String$match === void 0 ? void 0 : _String$match.length) === 1;
}